16.114. cdist-type__postfix_postconf(7) — cdist 4.10.11 documentation

# 16.114. cdist-type__postfix_postconf(7)

## 16.114.1. NAME

cdist-type__postfix_postconf - Configure postfix main.cf

## 16.114.2. DESCRIPTION

See postconf(5) for possible keys and values.

Note that this type directly runs the postconf executable. It does not make changes to /etc/postfix/main.cf itself.

## 16.114.3. REQUIRED PARAMETERS

value
  the value for the postfix parameter

## 16.114.4. OPTIONAL PARAMETERS

key
  the name of the parameter. Defaults to __object_id

## 16.114.5. EXAMPLES

    __postfix_postconf mydomain --value somedomain.com

    __postfix_postconf bind-to-special-ip --key smtp_bind_address --value 127.0.0.5

## 16.114.6. SEE ALSO

postconf(5)

## 16.114.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.114.8. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.